pub(crate) struct BranchMeta {
pub ascii: u8,
pub local_length: usize,
pub cumulative_length: usize,
pub count: usize,
}Expand description
Intermediate metadata for a branch node under construction.
Fields
ascii: u8The lead byte for this branch. Formerly it was required to be an ASCII byte, but now it can be any byte.
local_length: usizeThe size in bytes of the trie data reachable from this branch.
cumulative_length: usizeThe size in bytes of this and all later sibling branches.
count: usizeThe number of later sibling branches, including this.
Implementations
Sourceimpl BranchMeta
impl BranchMeta
Sourcepub const fn default() -> Self
pub const fn default() -> Self
Creates a new empty BranchMeta.